Thunk

Struct Thunk 

pub struct Thunk<T>(/* private fields */);
A wrapper around a closure that can be executed exactly once by a worker in a Hive.

Implementations

Source

impl<T, E> Thunk<Result<T, E>>

pub fn fallible<F: FnOnce() -> Result<T, E> + Send + 'static>(f: F) -> Self