CloneQueen

Struct CloneQueen 

pub struct CloneQueen<W>(/* private fields */);
A Queen that can create a Worker type that implements Clone, by making copies of an existing instance of that Worker type.

Implementations

Source

impl<W: Worker + Clone> CloneQueen<W>

pub fn new(worker: W) -> Self